@@ -97,6 +97,11 @@ detect_from_os_release()
 		return
 	fi
 	
+	if [ "$os_id" = 'ubuntu' ] && printf -- '%s\n' "$version_id" | grep -Eqe '^21\.10$'; then
+		printf -- '%s\n' 'UBUNTU2110'
+		return
+	fi
+	
 }
 
 cmd_detect()
@@ -165,6 +170,11 @@ cmd_detect()
 		return
 	fi
 	
+	if [ -r '/etc/os-release' ] && grep -Eqe '^PRETTY_NAME=.*(Ubuntu[[:space:]]+21\.10|Mint[[:space:]]+21)' -- '/etc/os-release'; then
+		printf -- '%s\n' 'UBUNTU2110'
+		return
+	fi
+	
 	if [ -r '/etc/os-release' ] && grep -Eqe '^PRETTY_NAME=.*Debian[[:space:]]+GNU/Linux[[:space:]]+(stretch|9)([[:space:]]|/)' -- '/etc/os-release'; then
 		printf -- '%s\n' 'DEBIAN9'
 		return
@@ -217,7 +227,7 @@ show_ALMA8()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -315,7 +325,7 @@ show_CENTOS6()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -411,7 +421,7 @@ show_CENTOS7()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -509,7 +519,7 @@ show_CENTOS8()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -1052,7 +1062,7 @@ show_ORACLE7()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -1150,7 +1160,7 @@ show_RHEL8()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -1250,7 +1260,7 @@ show_ROCKY8()
         "rpm",
         "-qa",
         "--qf",
-        "%{Name}\\t%{Version}\\t%{Arch}\\tii\\n",
+        "%{Name}\\t%{EVR}\\t%{Arch}\\tii\\n",
         "--"
       ],
       "purge": [
@@ -1644,7 +1654,7 @@ show_UBUNTU2004()
     "LIBSSL": "libssl1.1",
     "MCELOG": "bash"
   },
-  "parent": "DEBIAN11",
+  "parent": "UBUNTU2110",
   "repo": {
     "codename": "focal",
     "keyring": "debian/repo/storpool-keyring.gpg",
@@ -1659,6 +1669,117 @@ show_UBUNTU2004()
 EOVARIANT_JSON
 }
 
+show_UBUNTU2110()
+{
+	cat <<'EOVARIANT_JSON'
+  {
+  "builder": {
+    "alias": "ubuntu-21.10",
+    "base_image": "ubuntu:impish",
+    "branch": "ubuntu/impish",
+    "kernel_package": "linux-headers",
+    "utf8_locale": "C.UTF-8"
+  },
+  "commands": {
+    "package": {
+      "install": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "apt-get",
+        "-q",
+        "-y",
+        "--no-install-recommends",
+        "install",
+        "--"
+      ],
+      "list_all": [
+        "dpkg-query",
+        "-W",
+        "-f",
+        "${Package}\\t${Version}\\t${Architecture}\\t${db:Status-Abbrev}\\n",
+        "--"
+      ],
+      "purge": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "apt-get",
+        "-q",
+        "-y",
+        "purge",
+        "--"
+      ],
+      "remove": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "apt-get",
+        "-q",
+        "-y",
+        "remove",
+        "--"
+      ],
+      "remove_impl": [
+        "env",
+        "DEBIAN_FRONTEND=noninteractive",
+        "dpkg",
+        "-r",
+        "--"
+      ],
+      "update_db": [
+        "apt-get",
+        "-q",
+        "-y",
+        "update"
+      ]
+    },
+    "pkgfile": {
+      "dep_query": [
+        "sh",
+        "-c",
+        "dpkg-deb -f -- \"$pkg\" 'Depends' | sed -e 's/ *, */,/g' | tr ',' \"\\n\""
+      ],
+      "install": [
+        "sh",
+        "-c",
+        "env DEBIAN_FRONTEND=noninteractive apt-get install --no-install-recommends --reinstall -y -o DPkg::Options::=--force-confnew -- $packages"
+      ]
+    }
+  },
+  "descr": "Ubuntu 21.10 LTS (Impish Indri)",
+  "detect": {
+    "filename": "/etc/os-release",
+    "os_id": "ubuntu",
+    "os_version_regex": "^21\\.10$",
+    "regex": "^ PRETTY_NAME= .* (?: Ubuntu \\s+ 21 \\. 10 | Mint \\s+ 21 ) "
+  },
+  "family": "debian",
+  "file_ext": "deb",
+  "initramfs_flavor": "update-initramfs",
+  "min_sys_python": "3.9",
+  "name": "UBUNTU2110",
+  "package": {
+    "BINDINGS_PYTHON": "python3",
+    "BINDINGS_PYTHON_CONFGET": "python3-confget",
+    "BINDINGS_PYTHON_SIMPLEJSON": "python3-simplejson",
+    "CGROUP": "cgroup-tools",
+    "CPUPOWER": "linux-tools-generic",
+    "LIBSSL": "libssl1.1",
+    "MCELOG": "bash"
+  },
+  "parent": "DEBIAN12",
+  "repo": {
+    "codename": "impish",
+    "keyring": "debian/repo/storpool-keyring.gpg",
+    "req_packages": [
+      "ca-certificates"
+    ],
+    "sources": "debian/repo/storpool.sources",
+    "vendor": "ubuntu"
+  },
+  "systemd_lib": "lib/systemd/system"
+}
+EOVARIANT_JSON
+}
+
 
 cmd_show_all()
 {
@@ -1686,6 +1807,7 @@ cmd_show_all()
     "UBUNTU1604",
     "UBUNTU1804",
     "UBUNTU2004",
+    "UBUNTU2110",
     "DEBIAN9",
     "DEBIAN10",
     "DEBIAN11",
@@ -1736,11 +1858,14 @@ EOPROLOGUE
   echo ','
   printf -- '    "%s": ' 'UBUNTU2004'
   show_UBUNTU2004
+  echo ','
+  printf -- '    "%s": ' 'UBUNTU2110'
+  show_UBUNTU2110
   
 
 	cat <<'EOEPILOGUE'
   },
-  "version": "2.0.0"
+  "version": "2.1.0"
 }
 EOEPILOGUE
 }
@@ -1764,7 +1889,7 @@ EOPROLOGUE
 
 	cat <<'EOEPILOGUE'
   ,
-  "version": "2.0.0"
+  "version": "2.1.0"
 }
 EOEPILOGUE
 }
@@ -1806,7 +1931,7 @@ run_command()
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -1888,7 +2013,7 @@ fi
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -1970,7 +2095,7 @@ fi
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -2052,7 +2177,7 @@ fi
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -2394,7 +2519,7 @@ fi
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -2476,7 +2601,7 @@ fi
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -2558,7 +2683,7 @@ fi
 							;;
 						
 						list_all)
-							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{Version}\t%{Arch}\tii\n' '--'  "$@"
+							$noop 'rpm' '-qa' '--qf' '%{Name}\t%{EVR}\t%{Arch}\tii\n' '--'  "$@"
 							;;
 						
 						purge)
@@ -2824,6 +2949,71 @@ fi
 			esac
 			;;
 		
+		UBUNTU2110)
+			case "$cmd_cat" in
+				
+				package)
+					case "$cmd_item" in
+						
+						install)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' '--no-install-recommends' 'install' '--'  "$@"
+							;;
+						
+						list_all)
+							$noop 'dpkg-query' '-W' '-f' '${Package}\t${Version}\t${Architecture}\t${db:Status-Abbrev}\n' '--'  "$@"
+							;;
+						
+						purge)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' 'purge' '--'  "$@"
+							;;
+						
+						remove)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'apt-get' '-q' '-y' 'remove' '--'  "$@"
+							;;
+						
+						remove_impl)
+							$noop 'env' 'DEBIAN_FRONTEND=noninteractive' 'dpkg' '-r' '--'  "$@"
+							;;
+						
+						update_db)
+							$noop 'apt-get' '-q' '-y' 'update'  "$@"
+							;;
+						
+
+						*)
+							echo "Invalid command '$cmd_item' in the '$cmd_cat' category" 1>&2
+							exit 1
+							;;
+					esac
+					;;
+				
+				pkgfile)
+					case "$cmd_item" in
+						
+						dep_query)
+							$noop 'sh' '-c' 'dpkg-deb -f -- "$pkg" 'Depends' | sed -e 's/ *, */,/g' | tr ',' "\n"'  "$@"
+							;;
+						
+						install)
+							$noop 'sh' '-c' 'env DEBIAN_FRONTEND=noninteractive apt-get install --no-install-recommends --reinstall -y -o DPkg::Options::=--force-confnew -- $packages'  "$@"
+							;;
+						
+
+						*)
+							echo "Invalid command '$cmd_item' in the '$cmd_cat' category" 1>&2
+							exit 1
+							;;
+					esac
+					;;
+				
+
+				*)
+					echo "Invalid command category '$cmd_cat'" 1>&2
+					exit 1
+					;;
+			esac
+			;;
+		
 
 		*)
 			echo "Internal error: invalid variant '$name'" 1>&2
@@ -3041,6 +3231,12 @@ cmd_repo_add()
 			
 			;;
 		
+		UBUNTU2110)
+			
+			repo_add_deb 'UBUNTU2110' "$vdir" "$repotype" 'debian/repo/storpool.sources' 'debian/repo/storpool-keyring.gpg' 'ca-certificates'
+			
+			;;
+		
 	esac
 
 	install -o root -g root -m 755 -- "$0" /usr/sbin/sp_variant
@@ -3086,7 +3282,7 @@ cmd_command()
 
 cmd_features()
 {
-	echo 'Features: format=1.3 version=2.0.0'
+	echo 'Features: format=1.3 version=2.1.0'
 }
 
 case "$1" in
@@ -3190,6 +3386,10 @@ case "$1" in
 				show_variant 'UBUNTU2004'
 				;;
 			
+			UBUNTU2110)
+				show_variant 'UBUNTU2110'
+				;;
+			
 
 			*)
 				usage 1>&2
